# Contributor CI

![https://raw.githubusercontent.com/vsoch/contributor-ci/main/docs/assets/img/contributor-ci.png](https://raw.githubusercontent.com/vsoch/contributor-ci/main/docs/assets/img/contributor-ci.png)

[![GitHub Marketplace](https://img.shields.io/static/v1?label=Marketplace&message=contributor-action&color=blue?style=flat&logo=github)](https://github.com/marketplace/actions/contributor-ci-action)
[![License](https://img.shields.io/badge/license-MIT-brightgreen)](https://github.com/vsoch/contributor-ci-action/blob/master/LICENSE)

Contributor CI provides tools and visualizations for analyzing contributions. You
can read more about the library in the [documentation](https://contributor-ci.readthedocs.io/)
and releases are available on [pypi](https://pypi.org/project/contributor-ci).

![https://raw.githubusercontent.com/vsoch/contributor-ci/main/docs/assets/img/cci-interface.png](https://raw.githubusercontent.com/vsoch/contributor-ci/main/docs/assets/img/cci-interface.png)

## Thanks

The graphQL queries come from [llnl.github.io](https://github.com/LLNL/llnl.github.io) which is released
under an [MIT license](.github/LICENSE-LLNL).

## TODO

 - contributor friendliness assessment should discover a new repo, if a file doesn't exist, open a PR
 - tests
